@@ -15,8 +15,8 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-// $Name: IMKIT_0_4_1 $
-// $Id: engine_uim.cpp,v 1.31 2004/03/16 16:23:09 yamaken Exp $
+// $Name: IMKIT_0_4_2 $
+// $Id: engine_uim.cpp,v 1.32 2004/04/14 12:04:27 yamaken Exp $
 
 #include <ctype.h>
 #include <string.h>
@@ -505,7 +505,7 @@ UIMEngine::select_candidate(Candidates::size_type nth) {
 }
 
 void
-UIMEngine::cb_commit(void *_this, char *str) {
+UIMEngine::cb_commit(void *_this, const char *str) {
   ((UIMEngine *)_this)->slot_commit(str);
 }
 
@@ -515,7 +515,7 @@ UIMEngine::cb_clear(void *_this) {
 }
 
 void
-UIMEngine::cb_pushback(void *_this, int attr, char *str) {
+UIMEngine::cb_pushback(void *_this, int attr, const char *str) {
   ((UIMEngine *)_this)->slot_pushback(attr, str);
 }
 
@@ -555,7 +555,7 @@ UIMEngine::cb_candidate_win_deactivate(void *_this) {
 }
 
 void
-UIMEngine::slot_commit(char *str) {
+UIMEngine::slot_commit(const char *str) {
   QString unicode_str;
 
 #ifdef IMKIT_UIM_USE_UIM_CONVERTER
@@ -572,7 +572,7 @@ UIMEngine::slot_clear(void) {
 }
 
 void
-UIMEngine::slot_pushback(int attr, char *str) {
+UIMEngine::slot_pushback(int attr, const char *str) {
   QString qstr;
 
 #ifdef IMKIT_UIM_USE_UIM_CONVERTER
