@@ -15,8 +15,8 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-// $Name: IMKIT_0_4_1 $
-// $Id: engine_uim.h,v 1.17 2004/03/11 05:39:46 yamaken Exp $
+// $Name: IMKIT_0_4_2 $
+// $Id: engine_uim.h,v 1.18 2004/04/14 12:04:28 yamaken Exp $
 
 #ifndef IMKIT_ENGINE_UIM_H
 #define IMKIT_ENGINE_UIM_H
@@ -103,9 +103,9 @@ protected:
 
 protected:
   //callback interface to adapt to UIM API
-  static void cb_commit(void *_this, char *str);
+  static void cb_commit(void *_this, const char *str);
   static void cb_clear(void *_this);
-  static void cb_pushback(void *_this, int attr, char *str);
+  static void cb_pushback(void *_this, int attr, const char *str);
   static void cb_update(void *_this);
   static void cb_set_mode(void *_this, int mode);
   static void cb_set_mode_list_update(void *_this);
@@ -117,9 +117,9 @@ protected:
 
 protected slots:
   //internal slots that receives UIM callbacks
-  virtual void slot_commit(char *str);
+  virtual void slot_commit(const char *str);
   virtual void slot_clear(void);
-  virtual void slot_pushback(int attr, char *str);
+  virtual void slot_pushback(int attr, const char *str);
   virtual void slot_update(void);
   virtual void slot_set_mode(int mode);
   virtual void slot_set_mode_list_update(void);
