@@ -15,8 +15,8 @@
 // along with this program; if not, write to the Free Software
 // Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
-// $Name: IMKIT_0_4_1 $
-// $Id: uim_keyevent.cpp,v 1.14 2004/04/12 02:14:57 yamaken Exp $
+// $Name: IMKIT_0_4_2 $
+// $Id: uim_keyevent.cpp,v 1.15 2004/04/14 12:04:31 yamaken Exp $
 
 #include <ctype.h>
 #include "keyfilter.h"
@@ -219,13 +219,22 @@ UIMKeyEvent::UIMKeyEvent(const QKeyEvent &e)
   // Ctrl-h : Qt::Key_cent
   // Ctrl-j : Qt::Key_sterling
   keycode = q2u_keycode.ordinary_map.lookup(qt_keycode);
-  if (keycode == (UKey)0
+  if (keycode == (UKey)0) {
+    if (isascii(chr.unicode())
+        && (isgraph(chr.latin1())
+            || isspace(chr.latin1())
+            || iscntrl(chr.latin1())))
+    {
+      keycode = (UKey)imkit_strip_control(chr.latin1());
+    } else {
+      keycode = UKey_Other;
+    }
+  }
 #else
   if (iscntrl(e.ascii()) && !isascii(qt_keycode)) {
     keycode = q2u_keycode.ordinary_map.lookup(qt_keycode);
   } else if (isascii(qt_keycode)
              && qt_keycode
-#endif
              && (isgraph(chr.latin1())
                  || isspace(chr.latin1())
                  || iscntrl(chr.latin1())))
@@ -234,6 +243,7 @@ UIMKeyEvent::UIMKeyEvent(const QKeyEvent &e)
   } else {
     keycode = q2u_keycode.ordinary_map.lookup(qt_keycode);
   }
+#endif
   modifiers = q2u_convert_modifier_state(qt_modifier_state);
   is_press = (e.type() == QEvent::KeyPress);
   accepted = e.isAccepted();
